@@ -21,9 +21,9 @@ print.Rcpp_POSet <- function(x, max = NULL, ...) {
     max <- getOption("max.print")
   m <- min(n, max)
   cat("elements:\n")
-  cat(e[1:m])
+  cat(e[1:m], sep = ", ")
   if (n > m)
-    cat(" ...")
+    cat(", ...")
   cat("\n")
   rm(e)
   x <- x$comparabilities()
