@@ -22,11 +22,11 @@
 print.summary_poset <- function(x, ...) {
   if (x$comparabilities_number == 0) {
     if (x$elements_number > 1) cat("anti-chain of", x$elements_number, "elements\n")
-  } else if (x$comparabilities_number == x$elements_number * (x$elements_number - 1)/2)
+  } else if (x$comparabilities_number == x$elements_number^2) # * (x$elements_number - 1)/2)
     cat("chain of", x$elements_number, "elements\n")
   else cat(
     x$elements_number, " elements\n",
-    x$comparabilities_number, " strict comparabilities\n",
+    x$comparabilities_number, " comparabilities\n",
     nrow(x$incomparabilities), " incomparabilities\n",
     sep = ""
   )
